Learn R Programming

climtrends (version 1.0.5)

FindOutliersSD: Find outliers based on quantiles

Description

FindOutliersSD returns the position of the values outside the allowed range by a criteria based on the standard deviation, mean-coef*sd

Usage

FindOutliersSD(dataSeries,coef=3)

Arguments

dataSeries
time series of climate data
coef
coefficient, 1=68

Value

  • Vector with the positions of the outliers.

source

Leys C, Ley C, Klein O, Bernard P, Licata L, 2013 Detecting outliers: Do not use standard deviation around the mean, use absolute deviation around the median Journal of Experimental Social Psychology volume 49, number 4 url{http://www.sciencedirect.com/science/article/pii/S0022103113000668}

References

Leys C, Ley C, Klein O, Bernard P, Licata L, 2013 Detecting outliers: Do not use standard deviation around the mean, use absolute deviation around the median Journal of Experimental Social Psychology volume 49, number 4 url{http://www.sciencedirect.com/science/article/pii/S0022103113000668}

Examples

Run this code
y = c(1, 3, 3, 6, 8, 10, 10, 1000)
FindOutliersSD(y,2)

Run the code above in your browser using DataLab