Learn R Programming

climtrends (version 1.0.5)

FindOutliersTrimmedMeans: Find outliers based on trimmed means

Description

FindOutliersTrimmedMeans returns the position of the values outside the allowed range by a criteria based on trimmed means.

Usage

FindOutliersTrimmedMeans(dataSeries, percentTrim=0.1, coef=3)

Arguments

dataSeries
time series of climate data
percentTrim
percentage to trim
coef
coefficient

Value

  • Vector with the positions of the outliers.

Examples

Run this code
FindOutliersTrimmedMeans(c(2, 4, 6, 7, 11, 21, 81, 90, 105, 121))

Run the code above in your browser using DataLab