Learn R Programming

climtrends (version 1.0.5)

FindOutliersZscore: Find outliers based on the z-score

Description

FindOutliersZscore returns the position of the values outside the allowed range by a criteria based on the z-score, abs(Z)>coef. FindOutliersModifiedZscore uses the modified z-score.

Usage

FindOutliersZscore(dataSeries, coef=2.5)

Arguments

dataSeries
time series of climate data
coef
coefficient

Value

  • Vector with the positions of the outliers.

Examples

Run this code
FindOutliersZscore(c(2, 4, 6, 7, 11, 21, 81, 90, 105, 121))

Run the code above in your browser using DataLab