Learn R Programming

climtrends (version 1.0.5)

PlotHomog: Plot the graphics for many homogenization methods

Description

PlotHomog plot the graphics for many homogenization methods with an indication of the peak and significance levels.

Usage

PlotHomog(dataYearSeries=NA,refYearSeries=NA,diffFlag=TRUE,
homogenization=SNHTabsolute,levelSignificance=c(99,95),
criticalValues=climtrends::SNHT.Critical.Values,posLegend="topright",rowbycol=NULL)

Arguments

dataYearSeries
dataframe with climate data
refYearSeries
dataframe with climate data (reference)
diffFlag
logical TRUE=difference, FALSE=ratio
homogenization
homogenization test
levelSignificance
level of significance
criticalValues
critical values for the homogenization test
posLegend
position of the legend
rowbycol
vector with (rows, columns)

Value

  • none.

Examples

Run this code
# xgdcnCA008201000.dat is from ECA COLLEGEVILLE temperature
setwd(system.file('extdata/', package='climtrends'))
dailyCollegeville <- ReadGHCNymd('xgdcnCA008201000.dat')
yearlyCollegeville=YearFuncFromDay(dailyCollegeville)
colnames(yearlyCollegeville) <- c('year','temperature')
PlotHomog(yearlyCollegeville)

Run the code above in your browser using DataLab