SNHT.TwoDifferentSDs.Critical.Values: Critical values for the standard normal homogeneity test (SNHT) for two different SDs
Description
SNHT.TwoDifferentSDs.Critical.Values contains the critical
values for the SNHT test for 2 different SDs from Alexandersson and Moberg (1997).Usage
SNHT.TwoDifferentSDs.Critical.Values
format
This data frame contains 2 columns (90.00 and 108 rows (n=10, 12, 14, 16, ..., 15000, 20000, 50000) of data.source
ALEXANDERSSON, H. and MOBERG, A. (1997), HOMOGENIZATION OF SWEDISH TEMPERATURE DATA.
PART I: HOMOGENEITY TEST FOR LINEAR TRENDS. Int. J. Climatol., 17: 25–34.
doi: 10.1002/(SICI)1097-0088(199701)17:1<25::aid-joc103>3.0.CO;2-JTuomenvirta, H., 2002: Homogeneity testing and adjustment of climatic time series in Finland. Geophysica, 38(1-2), 15-41.
25::aid-joc103>References
ALEXANDERSSON, H. and MOBERG, A. (1997), HOMOGENIZATION OF SWEDISH TEMPERATURE DATA.
PART I: HOMOGENEITY TEST FOR LINEAR TRENDS. Int. J. Climatol., 17: 25–34.
doi: 10.1002/(SICI)1097-0088(199701)17:1<25::aid-joc103>3.0.CO;2-JTuomenvirta, H., 2002: Homogeneity testing and adjustment of climatic time series in Finland. Geophysica, 38(1-2), 15-41.
25::aid-joc103>Examples
Run this codedata(SNHT.TwoDifferentSDs.Critical.Values)
SNHT.TwoDifferentSDs.Critical.Values
Run the code above in your browser using DataLab