SNHT.TwoShifts.Critical.Values: Critical values for the standard normal homogeneity test (SNHT) for two shifts
Description
SNHT.TwoShifts.Critical.Values contains the critical
values for the SNHT test for 2 shifts from Alexandersson (1995).Usage
SNHT.TwoShifts.Critical.Values
format
This data frame contains 2 columns (90.00 and 108 rows (n=10, 12, 14, 16, ..., 15000, 20000, 50000) of data.source
Alexandersson, H., 1995. Homogeneity testing, multiple breaks and trends.
Proceedings of the Sixth International Meeting on Statistical Climatology,
Galway, Ireland, 439-441.Tuomenvirta, H., 2002: Homogeneity testing and adjustment of climatic time series in Finland. Geophysica, 38(1-2), 15-41.
References
Alexandersson, H., 1995. Homogeneity testing, multiple breaks and trends.
Proceedings of the Sixth International Meeting on Statistical Climatology,
Galway, Ireland, 439-441.Tuomenvirta, H., 2002: Homogeneity testing and adjustment of climatic time series in Finland. Geophysica, 38(1-2), 15-41.
Examples
Run this codedata(SNHT.TwoShifts.Critical.Values)
SNHT.TwoShifts.Critical.Values
Run the code above in your browser using DataLab