Learn R Programming

climtrends (version 1.0.5)

SiegelTukey: annual mean of the absolute day-to-day differences of DTR (SiegelTukey)

Description

SiegelTukey returns the annual mean of the absolute day-to-day differences of the diurnal temperature range (SiegelTukey).

Usage

SiegelTukey(x,y,id.col=FALSE,adjust.median=FALSE,rnd=-1,alternative="two.sided",
mu=0 ,paired=FALSE,exact=FALSE,correct=TRUE,conf.int=FALSE,conf.level=0.95,
showresult=TRUE, returnresult=TRUE)

Arguments

x
vector of data
y
Data of the second group (if id.col=FALSE) or group indicator (if id.col=TRUE). In the latter case, y MUST take 1 or 2 to indicate observations of group 1 and 2, respectively, and x must contain the data for both groups.
id.col
If FALSE (default), then x and y are the data columns for group 1 and 2, respectively. If TRUE, the y is the group indicator.
adjust.median
Should between-group differences in medians be leveled before performing the test? In certain cases, the Siegel-Tukey test is susceptible to median differences and may indicate significant differences in variability that, in reality, stem from differences
rnd
Should the data be rounded and, if so, to which decimal? The default (-1) uses the data as is. Otherwise, rnd must be a non-negative integer. Typically, this option is not needed. However, occasionally, differences in the precision with which certain func
alternative
"one.sided" or "two.sided".
mu
mu.
paired
Logical, TRUE=paired, FALSE=not paired.
exact
Logical, TRUE=paired, FALSE=.
correct
Logical, TRUE=paired, FALSE=.
conf.int
Confidence interval.
conf.level
Confidence level.
showresult
Logical, show the result or not.
returnresult
Logical, return the result or not.

Value

  • groupmedian1Group median 1
  • groupmedian2Group median 2
  • testmediandifferencesWilcoxon-test for between-group differences in median (after the median adjustment if specified)
  • wilcox.test.p.valueWilcoxon-test for between-group differences in median (after the median adjustment if specified)
  • wilcox.test.null.valueWilcoxon-test for between-group differences in median (after the median adjustment if specified)
  • unique.x.tieadjusted.rankUnique values of x and their tie-adjusted Siegel-Tukey ranks
  • tieadjusted.ranks.group1Tie-adjusted Siegel-Tukey ranks of group 1
  • tieadjusted.ranks.group2Tie-adjusted Siegel-Tukey ranks of group 2
  • wilcoxon.WWilcoxon-test for between-group differences in median (after the median adjustment if specified)
  • wilcoxon.p.valueWilcoxon-test for between-group differences in median (after the median adjustment if specified)

source

Daniel Malter, 2012 https://stat.ethz.ch/pipermail/r-help/2010-February/229215.html

References

Sidney Siegel and John Wilder Tukey, 1960 A nonparametric sum of ranks procedure for relative spread in unpaired samples. Journal of the American Statistical Association.

David J. Sheskin, 2004 Handbook of parametric and nonparametric statistical procedures. 3rd edition. Chapman and Hall/CRC. Boca Raton, FL.

Richard H. McCuen, 2002 Modeling Hydrologic Change: Statistical Methods CRC Press

Examples

Run this code
x=c(4,4,5,5,6,6)
y=c(0,0,1,9,10,10)
SiegelTukey(x,y)

Run the code above in your browser using DataLab